@@ -1,6 +1,6 @@
 /*
  * asapm is the APM (Advanced Power Management) monitor utility for X Windows
- * Copyright (c) 1998  Albert Dorofeev <Albert@mail.dma.be>
+ * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
  * For the updates see http://bewoner.dma.be/Albert/linux/
  *
  * This software is distributed under GPL. For details see LICENSE file.
@@ -250,6 +250,10 @@ void initializeWindow(int argc, char** argv,
 	char ** alphabet;
 	int color_depth;
 	int tmp;
+	int result;
+	int x_negative = 0;
+	int y_negative = 0;
+/*	XIconSize * xiconsize; */
 
 	mainDisplay = XOpenDisplay(display_name);
 	if ( ! mainDisplay ) {
@@ -302,28 +306,62 @@ void initializeWindow(int argc, char** argv,
 		exit(1);
 	}
 
-	SizeHints.flags= USSize|USPosition|PMinSize|PMaxSize;
+	if (strlen(mainGeometry)) {
+		/* Check the user-specified size */
+		result = XParseGeometry(
+			mainGeometry,
+			&SizeHints.x,
+			&SizeHints.y,
+			&SizeHints.width,
+			&SizeHints.height
+			);
+		if (result & XNegative) 
+			x_negative = 1;
+		if (result & YNegative) 
+			y_negative = 1;
+	}
+	SizeHints.flags= USSize|USPosition;
 	SizeHints.x = 0;
 	SizeHints.y = 0;
 	XWMGeometry(
 		mainDisplay,
 		screen,
-		mainGeometry,
-		NULL,
-		1,
-		& SizeHints,
-		&SizeHints.x,
-		&SizeHints.y,
-		&SizeHints.width,
-		&SizeHints.height,
-		&gravity
+		mainGeometry,		/* user_geometry */
+		NULL,			/* default_geometry */
+		1,			/* border_width */
+		& SizeHints,		/* hints */
+		&SizeHints.x,		/* x_return */
+		&SizeHints.y,		/* y_return */
+		&SizeHints.width,	/* width_return */
+		&SizeHints.height,	/* height_return */
+		&gravity		/* gravity_return */
 		);
+/*	printf("Icon size: min %dx%d max %dx%d WM req %dx%d\n",
+		SizeHints.min_width, SizeHints.min_height,
+		SizeHints.max_width, SizeHints.max_height,
+		SizeHints.width, SizeHints.height);	*/
 	SizeHints.min_width = 
 	SizeHints.max_width =
 	SizeHints.width = backgroundXpm.attributes.width;
 	SizeHints.min_height =
 	SizeHints.max_height =
 	SizeHints.height= backgroundXpm.attributes.height;
+	SizeHints.flags |= PMinSize|PMaxSize;
+
+	/* Correct the offsets if the X/Y are negative */
+	SizeHints.win_gravity = NorthWestGravity;
+	if (x_negative) {
+		SizeHints.x -= SizeHints.width;
+		SizeHints.win_gravity = NorthEastGravity;
+	}
+	if (y_negative) {
+		SizeHints.y -= SizeHints.height;
+		if (x_negative)
+			SizeHints.win_gravity = SouthEastGravity;
+		else
+			SizeHints.win_gravity = SouthWestGravity;
+	}
+	SizeHints.flags |= PWinGravity;
 
 	mainWindow = XCreateSimpleWindow(
 		mainDisplay,		/* display */
@@ -350,7 +388,22 @@ void initializeWindow(int argc, char** argv,
 		);
 
 	XSetWMNormalHints(mainDisplay, mainWindow, &SizeHints);
+	XSetWMNormalHints(mainDisplay, iconWindow, &SizeHints);
 	status = XClearWindow(mainDisplay, mainWindow);
+	status = XClearWindow(mainDisplay, iconWindow);
+
+	/*xiconsize = XAllocIconSize();
+	xiconsize->min_width = 
+	xiconsize->max_width = SizeHints.width;
+	xiconsize->min_height =
+	xiconsize->max_height = SizeHints.height;
+	XSetIconSizes(mainDisplay,mainWindow,xiconsize,1);
+	XSetIconSizes(mainDisplay,iconWindow,xiconsize,1);
+	status = XGetIconSizes( mainDisplay,mainWindow,&xiconsize,&tmp );
+	printf("Got icon size: min %dx%d max %dx%d\n",
+		xiconsize->min_width, xiconsize->min_height,
+		xiconsize->max_width, xiconsize->max_height);
+	printf("Status %d, count %d\n", status, tmp);*/
 
 	status = XGetWindowAttributes(
 		mainDisplay,	/* display */
@@ -845,8 +898,13 @@ void DrawBattery( Window win )
 		);
 	if ( state.ac_line_status == AC_ONLINE )
 	{
-		/* set green color */
-		mainGCV.foreground = greenTextPixel;
+		if ( state.battery_status == BATTERY_CHARGING ) {
+			/* set red color */
+			mainGCV.foreground = redTextPixel;
+		} else {
+			/* set green color */
+			mainGCV.foreground = greenTextPixel;
+		}
 		XChangeGC(
 			mainDisplay,
 			mainGC,
