@@ -108,7 +108,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asapm : Advanced Power Management monitor version 2.7\n");
+        printf("asapm : Advanced Power Management monitor version 2.8\n");
 }               
 
 /*
@@ -160,7 +160,7 @@ void    parsecmdline(int argc, char *argv[])
         for (i=1; i<argc; i++) {
                 argument=argv[i];
                 if (argument[0]=='-') {
-			if ( !strncmp(argv[i], "-f", 2) ) {
+			if ( !strncmp(argv[i], "-rc", 3) ) {
 				++i;
                         } else if (!strncmp(argument,"-withdrawn",10)) {
                                 withdrawn=1;
